@@ -29,11 +29,6 @@
 #include <util/unused.h>
 
 #ifdef HAVE_EXPAT
-#ifdef _WIN32
-// ensure that the expat functions get the correct storage class
-// declarations also on MinGW
-#define XML_USE_MSC_EXTENSIONS 1
-#endif
 #include <expat.h>
 #endif
 
@@ -598,6 +593,7 @@ static htmltbl_t *mkTbl(htmllexstate_t *ctx, char **atts)
     htmltbl_t *tbl = gv_alloc(sizeof(htmltbl_t));
 
     tbl->row_count = SIZE_MAX; // flag that table is a raw, parsed table
+    tbl->rows = (rows_t){.dtor = free_ritem};
     tbl->cellborder = -1; // unset cell border attribute
     doAttrs(ctx, tbl, tbl_items, sizeof(tbl_items) / ISIZE, atts, "<TABLE>");
 
