@@ -39,8 +39,8 @@
  * NULL otherwise
  */
 Agraph_t *sameG(void *p1, void *p2, char *fn, char *msg) {
-  Agobj_t *obj1 = OBJ(p1);
-  Agobj_t *obj2 = OBJ(p2);
+  Agobj_t *obj1 = p1;
+  Agobj_t *obj2 = p2;
   Agraph_t *root;
 
   root = agroot(agraphof(obj1));
@@ -820,41 +820,3 @@ char *colorx(Expr_t *ex, const char *incolor, char *fmt) {
   agxbfree(&fp);
   return result;
 }
-
-#ifndef _WIN32
-
-#include <sys/param.h>
-#include <sys/times.h>
-#include <sys/types.h>
-#include <unistd.h>
-
-#ifndef HZ
-#define HZ 60
-#endif
-typedef struct tms mytime_t;
-#define GET_TIME(S) times(&(S))
-#define DIFF_IN_SECS(S, T)                                                     \
-  ((S.tms_utime + S.tms_stime - T.tms_utime - T.tms_stime) / (double)HZ)
-
-#else
-
-#include <time.h>
-
-typedef clock_t mytime_t;
-#define GET_TIME(S) S = clock()
-#define DIFF_IN_SECS(S, T) ((S - T) / (double)CLOCKS_PER_SEC)
-
-#endif
-
-static mytime_t T;
-
-void gvstart_timer(void) { GET_TIME(T); }
-
-double gvelapsed_sec(void) {
-  mytime_t S;
-  double rv;
-
-  GET_TIME(S);
-  rv = DIFF_IN_SECS(S, T);
-  return rv;
-}
