@@ -19,9 +19,6 @@
 #include "config.h"
 
 #include <time.h>
-#ifndef _WIN32
-#include <unistd.h>
-#endif
 #include <neatogen/neato.h>
 #include <pack/pack.h>
 #include <neatogen/stress.h>
@@ -38,6 +35,7 @@
 #include <stdatomic.h>
 #include <stdbool.h>
 #include <stddef.h>
+#include <util/agxbuf.h>
 #include <util/alloc.h>
 #include <util/bitarray.h>
 #include <util/gv_ctype.h>
@@ -89,7 +87,7 @@ bool user_pos(attrsym_t *posptr, attrsym_t *pinptr, node_t *np, int nG) {
 	    if (PSinputscale > 0.0) {
 		int i;
 		for (i = 0; i < Ndim; i++)
-		    pvec[i] = pvec[i] / PSinputscale;
+		    pvec[i] /= PSinputscale;
 	    }
 	    if (Ndim > 3)
 		jitter_d(np, nG, 3);
@@ -168,8 +166,8 @@ void neato_cleanup(graph_t * g)
     neato_cleanup_graph(g);
 }
 
-static int numFields(const char *pos) {
-    int cnt = 0;
+static size_t numFields(const char *pos) {
+    size_t cnt = 0;
     char c;
 
     do {
@@ -259,62 +257,53 @@ static void freeClusterData(cluster_data c) {
 }
 #endif
 
-/* user_spline:
- * Attempt to use already existing pos info for spline
+/* Attempt to use already existing pos info for spline
  * Return 1 if successful, 0 otherwise.
  * Assume E_pos != NULL and ED_spl(e) == NULL.
  */
 static int user_spline(attrsym_t * E_pos, edge_t * e)
 {
-    char *pos;
-    int i, n, npts, nc;
+    int nc;
     pointf *pp;
     double x, y;
-    int sflag = 0, eflag = 0;
+    bool sflag = false, eflag = false;
     pointf sp = { 0, 0 }, ep = { 0, 0};
     bezier *newspl;
-    int more = 1;
     static atomic_flag warned;
 
-    pos = agxget(e, E_pos);
+    const char *pos = agxget(e, E_pos);
     if (*pos == '\0')
 	return 0;
 
     uint32_t stype, etype;
     arrow_flags(e, &stype, &etype);
-    do {
+    for (bool more = true; more; ) {
 	/* check for s head */
-	i = sscanf(pos, "s,%lf,%lf%n", &x, &y, &nc);
-	if (i == 2) {
-	    sflag = 1;
-	    pos = pos + nc;
-	    sp.x = x;
-	    sp.y = y;
+	if (sscanf(pos, "s,%lf,%lf%n", &x, &y, &nc) == 2) {
+	    sflag = true;
+	    pos += nc;
+	    sp = (pointf){.x = x, .y = y};
 	}
 
 	/* check for e head */
-	i = sscanf(pos, " e,%lf,%lf%n", &x, &y, &nc);
-	if (i == 2) {
-	    eflag = 1;
-	    pos = pos + nc;
-	    ep.x = x;
-	    ep.y = y;
+	if (sscanf(pos, " e,%lf,%lf%n", &x, &y, &nc) == 2) {
+	    eflag = true;
+	    pos += nc;
+	    ep = (pointf){.x = x, .y = y};
 	}
 
-	npts = numFields(pos); // count potential points
-	n = npts;
-	if (n < 4 || n % 3 != 1) {
+	const size_t npts = numFields(pos); // count potential points
+	if (npts < 4 || npts % 3 != 1) {
 	    gv_free_splines(e);
 	    if (!atomic_flag_test_and_set(&warned)) {
 		agwarningf("pos attribute for edge (%s,%s) doesn't have 3n+1 points\n", agnameof(agtail(e)), agnameof(aghead(e)));
 	    }
 	    return 0;
 	}
-	pointf *ps = gv_calloc(n, sizeof(pointf));
+	pointf *ps = gv_calloc(npts, sizeof(pointf));
 	pp = ps;
-	while (n) {
-	    i = sscanf(pos, "%lf,%lf%n", &x, &y, &nc);
-	    if (i < 2) {
+	for (size_t n = npts; n > 0; --n) {
+	    if (sscanf(pos, "%lf,%lf%n", &x, &y, &nc) < 2) {
 		if (!atomic_flag_test_and_set(&warned)) {
 		    agwarningf("syntax error in pos attribute for edge (%s,%s)\n", agnameof(agtail(e)), agnameof(aghead(e)));
 		}
@@ -323,20 +312,17 @@ static int user_spline(attrsym_t * E_pos, edge_t * e)
 		return 0;
 	    }
 	    pos += nc;
-	    pp->x = x;
-	    pp->y = y;
+	    *pp = (pointf){.x = x, .y = y};
 	    pp++;
-	    n--;
 	}
  	while (gv_isspace(*pos)) pos++;
 	if (*pos == '\0')
-	    more = 0;
+	    more = false;
 	else
 	    pos++;
 
 	/* parsed successfully; create spline */
-	assert(npts >= 0);
-	newspl = new_spline(e, (size_t)npts);
+	newspl = new_spline(e, npts);
 	if (sflag) {
 	    newspl->sflag = stype;
 	    newspl->sp = sp;
@@ -345,11 +331,11 @@ static int user_spline(attrsym_t * E_pos, edge_t * e)
 	    newspl->eflag = etype;
 	    newspl->ep = ep;
 	}
-	for (i = 0; i < npts; i++) {
+	for (size_t i = 0; i < npts; i++) {
 	    newspl->list[i] = ps[i];
 	}
 	free(ps);
-    } while (more);
+    }
 
     if (ED_label(e))
 	set_label(e, ED_label(e), "lp");
@@ -373,8 +359,7 @@ static int user_spline(attrsym_t * E_pos, edge_t * e)
  /* Indicates the amount of edges with position information */
 typedef enum { NoEdges, SomeEdges, AllEdges } pos_edge;
 
-/* nop_init_edges:
- * Check edges for position info.
+/* Check edges for position info.
  * If position info exists, check for edge label positions.
  * Return number of edges with position info.
  */
@@ -401,14 +386,11 @@ static pos_edge nop_init_edges(Agraph_t * g)
     if (nedges) {
 	if (nedges == agnedges(g))
 	    return AllEdges;
-	else
-	    return SomeEdges;
-    } else
-	return NoEdges;
+	return SomeEdges;
+    }
+    return NoEdges;
 }
 
-/* freeEdgeInfo:
- */
 static void freeEdgeInfo (Agraph_t * g)
 {
     node_t *n;
@@ -429,15 +411,14 @@ static void freeEdgeInfo (Agraph_t * g)
  * Scans for a correct bb attribute. If available, sets it
  * in the graph and returns 1.
  */
-#define BS "%lf,%lf,%lf,%lf"
-
 static int chkBB(Agraph_t * g, attrsym_t * G_bb, boxf* bbp)
 {
     char *s;
     boxf bb;
 
     s = agxget(g, G_bb);
-    if (sscanf(s, BS, &bb.LL.x, &bb.LL.y, &bb.UR.x, &bb.UR.y) == 4) {
+    if (sscanf(s, "%lf,%lf,%lf,%lf", &bb.LL.x, &bb.LL.y, &bb.UR.x,
+               &bb.UR.y) == 4) {
 	if (bb.LL.y > bb.UR.y) {
 	/* If the LL.y coordinate is bigger than the UR.y coordinate,
          * we assume the input was produced using -y, so we normalize
@@ -447,8 +428,8 @@ static int chkBB(Agraph_t * g, attrsym_t * G_bb, boxf* bbp)
 	}
 	*bbp = bb;
 	return 1;
-    } else
-	return 0;
+    }
+    return 0;
 }
 
 static void add_cluster(Agraph_t * g, Agraph_t * subg)
@@ -464,8 +445,7 @@ static void add_cluster(Agraph_t * g, Agraph_t * subg)
 
 static void nop_init_graphs(Agraph_t *, attrsym_t *, attrsym_t *);
 
-/* dfs:
- * Process subgraph subg of parent graph g
+/* Process subgraph subg of parent graph g
  * If subg is a cluster, add its bounding box, if any; attach to
  * cluster array of parent, and recursively initialize subg.
  * If not a cluster, recursively call this function on the subgraphs
@@ -489,8 +469,7 @@ dfs(Agraph_t * subg, Agraph_t * parentg, attrsym_t * G_lp, attrsym_t * G_bb)
     }
 }
 
-/* nop_init_graphs:
- * Read in clusters and graph label info.
+/* Read in clusters and graph label info.
  * A subgraph is a cluster if its name starts with "cluster" and
  * it has a valid bb.
  */
@@ -516,8 +495,7 @@ nop_init_graphs(Agraph_t * g, attrsym_t * G_lp, attrsym_t * G_bb)
     }
 }
 
-/* init_nop:
- * This assumes all nodes have been positioned.
+/* This assumes all nodes have been positioned.
  * It also assumes none of the relevant fields in A*info_t have been set.
  * The input may provide additional position information for
  * clusters, edges and labels. If certain position information
@@ -603,7 +581,7 @@ int init_nop(Agraph_t * g, int adjust)
 	    freeEdgeInfo (g);
 	    posEdges = NoEdges;
 	}
-	if (posEdges != AllEdges)
+	if (posEdges != AllEdges || Nop == 3)
 	    spline_edges0(g, false);   /* add edges */
 	else
 	    State = GVSPLINES;
@@ -628,7 +606,7 @@ static int neatoModel(graph_t * g)
 {
     char *p = agget(g, "model");
 
-    if (!p || streq(p, ""))    /* if p is NULL or "" */
+    if (!p || streq(p, ""))
 	return MODEL_SHORTPATH;
     if (streq(p, "circuit"))
 	return MODEL_CIRCUIT;
@@ -652,8 +630,6 @@ static int neatoModel(graph_t * g)
     return MODEL_SHORTPATH;
 }
 
-/* neatoMode:
- */
 static int neatoMode(graph_t * g)
 {
     char *str;
@@ -732,9 +708,7 @@ dfsCycle (vtx_data* graph, int i,int mode, node_t* nodes[])
     ND_onstack(np) = false;
 }
 
-/* acyclic:
- * Do a dfs of the vtx_data, looking for cycles, reversing edges.
- */
+/// do a dfs of the vtx_data, looking for cycles, reversing edges
 static void
 acyclic (vtx_data* graph, int nv, int mode, node_t* nodes[])
 {
@@ -754,8 +728,7 @@ acyclic (vtx_data* graph, int nv, int mode, node_t* nodes[])
 }
 #endif
 
-/* makeGraphData:
- * Create sparse graph representation via arrays.
+/* Create sparse graph representation via arrays.
  * Each node is represented by a vtx_data.
  * The index of each neighbor is stored in the edges array;
  * the corresponding edge lengths and weights go on ewgts and eweights.
@@ -935,8 +908,7 @@ static void initRegular(graph_t * G, int nG)
 #define REGULAR "regular"
 #define RANDOM  "random"
 
-/* setSeed:
- * Analyze "start" attribute. If unset, return dflt.
+/* Analyze "start" attribute. If unset, return dflt.
  * If it begins with self, regular, or random, return set init to same,
  * else set init to dflt.
  * If init is random, look for value integer suffix to use a seed; if not
@@ -972,11 +944,7 @@ setSeed (graph_t * G, int dflt, long* seedp)
 	long seed;
 	/* Check for seed value */
 	if (!gv_isdigit(*p) || sscanf(p, "%ld", &seed) < 1) {
-#if defined(_WIN32)
 	    seed = (unsigned) time(NULL);
-#else
-	    seed = (unsigned) getpid() ^ (unsigned) time(NULL);
-#endif
 	    agset(G, "start", ITOS(seed));
 	}
 	*seedp = seed;
@@ -984,8 +952,7 @@ setSeed (graph_t * G, int dflt, long* seedp)
     return init;
 }
 
-/* checkExp:
- * Allow various weights for the scale factor in used to calculate stress.
+/* Allow various weights for the scale factor in used to calculate stress.
  * At present, only 1 or 2 are allowed, with 2 the default.
  */
 #define exp_name "stresswt"
@@ -1000,8 +967,7 @@ static int checkExp (graph_t * G)
     return exp;
 }
 
-/* checkStart:
- * Analyzes start attribute, setting seed.
+/* Analyzes start attribute, setting seed.
  * If set,
  *   If start is regular, places nodes and returns INIT_REGULAR.
  *   If start is self, returns INIT_SELF.
@@ -1104,8 +1070,7 @@ void dumpOpts (ipsep_options* opp, int nv)
 }
 #endif
 
-/* majorization:
- * Solve stress using majorization.
+/* Solve stress using majorization.
  * Old neato attributes to incorporate:
  *  weight
  * mode will be MODE_MAJOR, MODE_HIER or MODE_IPSEP
@@ -1254,8 +1219,7 @@ static void subset_model(Agraph_t * G, int nG)
     freeGraphData(gp);
 }
 
-/* mds_model:
- * Assume the matrix already contains shortest path values.
+/* Assume the matrix already contains shortest path values.
  * Use the actual lengths provided the input for edges.
  */
 static void mds_model(graph_t * g)
@@ -1275,9 +1239,7 @@ static void mds_model(graph_t * g)
     }
 }
 
-/* kkNeato:
- * Solve using gradient descent a la Kamada-Kawai.
- */
+/// solve using gradient descent a la Kamada-Kawai
 static void kkNeato(Agraph_t * g, int nG, int model)
 {
     if (model == MODEL_SUBSET) {
@@ -1309,9 +1271,7 @@ static void kkNeato(Agraph_t * g, int nG, int model)
     solve_model(g, nG);
 }
 
-/* neatoLayout:
- * Use stress optimization to layout a single component
- */
+/// use stress optimization to layout a single component
 static void
 neatoLayout(Agraph_t * mg, Agraph_t * g, int layoutMode, int layoutModel,
   adjust_data* am)
@@ -1339,21 +1299,21 @@ neatoLayout(Agraph_t * mg, Agraph_t * g, int layoutMode, int layoutModel,
 	majorization(mg, g, nG, layoutMode, layoutModel, Ndim, am);
 }
 
-/* addZ;
- * If dimension == 3 and z attribute is declared,
+/* If dimension == 3 and z attribute is declared,
  * attach z value to nodes if not defined.
  */
 static void addZ (Agraph_t* g)
 {
     node_t* n;
-    char    buf[BUFSIZ];
+    agxbuf buf = {0};
 
     if (Ndim >= 3 && N_z) {
 	for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
-	    snprintf(buf, sizeof(buf), "%lf", POINTS_PER_INCH * ND_pos(n)[2]);
-	    agxset(n, N_z, buf);
+	    agxbprint(&buf, "%lf", POINTS_PER_INCH * ND_pos(n)[2]);
+	    agxset(n, N_z, agxbuse(&buf));
 	}
     }
+    agxbfree(&buf);
 }
 
 #ifdef IPSEPCOLA
@@ -1371,8 +1331,7 @@ addCluster (graph_t* g)
 }
 #endif
 
-/* doEdges:
- * Simple wrapper to compute graph's bb, then route edges after
+/* Simple wrapper to compute graph's bb, then route edges after
  * a possible aspect ratio adjustment.
  */
 static void doEdges(Agraph_t* g)
@@ -1381,8 +1340,6 @@ static void doEdges(Agraph_t* g)
     spline_edges0(g, true);
 }
 
-/* neato_layout:
- */
 void neato_layout(Agraph_t * g)
 {
     int layoutMode;
