@@ -48,7 +48,7 @@ int sfprint(FILE *f, Sffmt_t *format) {
     Argv_t argv;		/* for extf to return value     */
     Sffmt_t *ft;		/* format environment           */
 
-    int argp, argn;		/* arg position and number      */
+    int argn;		/* arg position and number      */
 
 #define SLACK		1024
     char buf[SF_MAXDIGITS + SLACK];
@@ -90,17 +90,17 @@ int sfprint(FILE *f, Sffmt_t *format) {
 
     while ((n = *form)) {
 	if (n != '%') {		/* collect the non-pattern chars */
-	    sp = (char *) form++;
-	    while (*form && *form != '%')
-		form += 1;
-	    n = form - sp;
-	    SFwrite(f, sp, n);
+	    size_t form_len = 1;
+	    while (form[form_len] != '\0' && form[form_len] != '%')
+		++form_len;
+	    SFwrite(f, form, form_len);
+	    form += form_len;
 	    continue;
 	} else
 	    form += 1;
 
 	flags = 0;
-	size = width = precis = base = n_s = argp = -1;
+	size = width = precis = base = n_s = -1;
 	ssp = _Sfdigits;
 	endep = ep = NULL;
 	endsp = sp = buf + (sizeof(buf) - 1);
@@ -134,8 +134,7 @@ int sfprint(FILE *f, Sffmt_t *format) {
 		    if (*t_str != '*')
 			n_str = (form - 1) - t_str;
 		    else {
-			t_str = _Sffmtintf(t_str + 1, &n);
-			FP_SET(-1, argn);
+			++argn;
 
 			FMTSET(ft, form, LEFTP, 0, 0, 0, 0, 0, NULL, 0);
 			n = ft->extf(&argv, ft);
@@ -203,8 +202,8 @@ int sfprint(FILE *f, Sffmt_t *format) {
 	  do_star:
 	    form += 1;		/* fall through */
 	case '*':
-	    form = _Sffmtintf(form, &n);
-	    n = FP_SET(-1, argn);
+	    form = _Sffmtintf(form);
+	    n = ++argn;
 
 	    FMTSET(ft, form, '.', dot, 0, 0, 0, 0, NULL, 0);
 	    if (ft->extf(&argv, ft) < 0)
@@ -244,8 +243,8 @@ int sfprint(FILE *f, Sffmt_t *format) {
 		for (n = *form; gv_isdigit(n); n = *++form)
 		    size = size * 10 + (n - '0');
 	    } else if (*form == '*') {
-		form = _Sffmtintf(form + 1, &n);
-		n = FP_SET(-1, argn);
+		form = _Sffmtintf(form + 1);
+		n = ++argn;
 
 		FMTSET(ft, form, 'I', sizeof(int), 0, 0, 0, 0, NULL, 0);
 		if (ft->extf(&argv, ft) < 0)
@@ -310,7 +309,7 @@ int sfprint(FILE *f, Sffmt_t *format) {
 	    }
 	}
 
-	argp = FP_SET(argp, argn);
+	++argn;
 	FMTSET(ft, form, fmt, size, flags, width, precis, base, t_str, n_str);
 	v = ft->extf(&argv, ft);
 
@@ -473,8 +472,10 @@ int sfprint(FILE *f, Sffmt_t *format) {
 			lv = -lv;
 		}
 		if (n_s < 0) {	/* base 10 */
-		    long long nv;
-		    sfucvt(lv, sp, nv, ssp, long long, unsigned long long);
+		    char scratch[41]; // space to print ≤128-bit integer
+		    const int nv = snprintf(scratch, sizeof(scratch), "%lld", lv);
+		    sp -= nv;
+		    memcpy(sp, scratch, (size_t)nv);
 		} else if (n_s > 0) {	/* base power-of-2 */
 		    do {
 			*--sp = ssp[lv & n_s];
@@ -525,7 +526,10 @@ int sfprint(FILE *f, Sffmt_t *format) {
 			v = -v;
 		}
 		if (n_s < 0) {	/* base 10 */
-		    sfucvt(v, sp, n, ssp, int, unsigned);
+		    char scratch[41]; // space to print ≤128-bit integer
+		    const int nv = snprintf(scratch, sizeof(scratch), "%d", v);
+		    sp -= nv;
+		    memcpy(sp, scratch, (size_t)nv);
 		} else if (n_s > 0) {	/* base power-of-2 */
 		    do {
 			*--sp = ssp[v & n_s];
